SystemOrganization addCategory: #'Magritte-Tests-Core'!
SystemOrganization addCategory: #'Magritte-Tests-Model'!
SystemOrganization addCategory: #'Magritte-Tests-Description'!
SystemOrganization addCategory: #'Magritte-Tests-Accessor'!
SystemOrganization addCategory: #'Magritte-Tests-Memento'!
SystemOrganization addCategory: #'Magritte-Tests-Relation'!
SystemOrganization addCategory: #'Magritte-Tests-Utility'!

TestCase subclass: #MADynamicObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCalculated
	| object dummy |
	object := MADynamicObject on: [ Time millisecondClockValue ].
	dummy := object yourself.
	
	(Delay forMilliseconds: 2) wait.
	self assert: dummy < object.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testCollection
	| object |
	object := MADynamicObject on: [ OrderedCollection with: 1 with: 2 ].
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testConstant
	| object |
	object := MADynamicObject on: [ self ].
	self assert: object = self.
	
	object := MADynamicObject on: [ 123 ].
	self assert: object = 123.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:40'!
testCounter
	| object |
	object := MADynamicObject on: [
		| counter |
		counter := counter isNil
			ifTrue: [ 1 ] 
			ifFalse: [ counter := counter + 1 ] ].

	self assert: object = 1.
	self assert: object yourself = 2.
	self assert: object yourself yourself = 3.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:38'!
testDynamic
	| object |
	object := MADynamicObject on: [
		| collection |
		collection isNil
			ifTrue: [ collection := OrderedCollection with: 1 with: 2 ]
			ifFalse: [ collection ] ].
	self assert: object size = 2.
	self assert: object first = 1.
	self assert: object second = 2.
	
	object add: 3.
	self assert: object size = 3.
	self assert: object first = 1.
	self assert: object second = 2.
	self assert: object third = 3.! !

!MADynamicObjectTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:46'!
testNilOrNotNil
	| object |
	object := MADynamicObject on: 'abc'.
	self deny: object isNil.
	self assert: object notNil.
	
	object := MADynamicObject on: nil.
	self assert: object isNil.
	self deny: object notNil.! !

TestCase subclass: #MAExtensionsTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

!MAExtensionsTest methodsFor: 'testing-integer' stamp: 'lr 10/17/2005 08:48'!
testFileSize
	self assert: (1000) asFileSize = '1000 B'.
	self assert: (1024) asFileSize = '1 KB'.

	self assert: (1000 * 1000) asFileSize = '976 KB'.
	self assert: (1024 * 1024) asFileSize = '1 MB'.

	self assert: (1000 * 1000 * 1000) asFileSize = '953 MB'.
	self assert: (1024 * 1024 * 1024) asFileSize = '1 GB'.

	self assert: (1000 * 1000 * 1000 * 1000) asFileSize = '931 GB'.
	self assert: (1024 * 1024 * 1024 * 1024) asFileSize = '1 TB'.

	" etc "! !

!MAExtensionsTest methodsFor: 'testing-string' stamp: 'lr 10/17/2005 08:58'!
testMatches
	self assert: ('' matches: '').
	self assert: ('zort' matches: '').
	self assert: ('zort' matches: 'o').
	self assert: ('zort' matches: 'O').
	self assert: ('zort' matches: '*').
	self assert: ('mobaz' matches: '*baz').
	self deny: ('mobazo' matches: '*baz').
	self assert: ('mobazo' matches: '*baz*').
	self deny: ('mozo' matches: '*baz*').
	self assert: ('foozo' matches: 'foo*').
	self deny: ('bozo' matches: 'foo*').
	self assert: ('foo23baz' matches: 'foo*baz').
	self assert: ('foobaz' matches: 'foo*baz').
	self deny: ('foo23bazo' matches: 'foo*baz').
	self assert: ('Foo' matches: 'foo').
	self deny: ('foobazort' matches: 'foo*baz*zort').
	self assert: ('foobazzort' matches: 'foo*baz*zort').
	self assert: ('afoo3zortthenfoo3zort' matches: '*foo#zort').
	self assert: ('afoodezortorfoo3zort' matches: '*foo*zort').! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 10/17/2005 08:41'!
testMoveDown
	| col |
	col := Array with: 1 with: 2 with: 3.

	self assert: (col moveDown: 1) = 2.
	self assert: col = #( 2 1 3 ).

	self assert: (col moveDown: 1) = 3.
	self assert: col = #( 2 3 1 ).

	self assert: (col moveDown: 1) = 3.
	self assert: col = #( 2 3 1 ).

	self assert: (col moveDown: 0) = 0.
	self assert: col = #( 2 3 1 ).! !

!MAExtensionsTest methodsFor: 'testing-collection' stamp: 'lr 10/17/2005 08:42'!
testMoveUp
	| col |
	col := Array with: 1 with: 2 with: 3.

	self assert: (col moveUp: 3) = 2.
	self assert: col = #( 1 3 2 ).

	self assert: (col moveUp: 3) = 1.
	self assert: col = #( 3 1 2 ).

	self assert: (col moveUp: 3) = 1.
	self assert: col = #( 3 1 2 ).

	self assert: (col moveUp: 0) = 0.
	self assert: col = #( 3 1 2 ).! !

TestCase subclass: #MAFileModelTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:19'!
testContents
	| model |
	model := MAFileModel new.
	self assert: model contents isEmpty.
	
	model contents: 'hello'.
	self assert: model contents = 'hello'.
	self assert: model size = 5.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 8/10/2005 19:58'!
testFilename
	| model |
	model := MAFileModel new.
	self assert: model filename isEmpty.
	self assert: model extension isEmpty.
	
	model filename: 'test.txt'.
	self assert: model filename = 'test.txt'.
	self assert: model extension = 'txt'.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:16'!
testIsEmpty
	| model |
	model := MAFileModel new.
	self assert: model isEmpty.
	
	model filename: 'foo.txt'.
	self assert: model isEmpty.
	
	model mimetype: 'text/plain'.
	self assert: model isEmpty.
	
	model contents: 'hello'.
	self deny: model isEmpty.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:18'!
testMimetype
	| model |
	model := MAFileModel new.
	self assert: model mimetype = 'application/octet-stream'.
	self assert: model maintype = 'application'.
	
	model filename: 'test.txt'.
	self assert: model mimetype = 'text/plain'.
	self assert: model maintype = 'text'.
	
	model mimetype: 'text/html'.
	self assert: model mimetype = 'text/html'.
	self assert: model maintype = 'text'.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeApplication
	| model |
	model := MAFileModel new
		mimetype: 'application/pdf';
		yourself.

	self assert: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.	! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeAudio
	| model |
	model := MAFileModel new
		mimetype: 'audio/mpeg';
		yourself.

	self deny: model isApplication.
	self assert: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeDefault
	| model |
	model := MAFileModel new.

	self assert: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeImage
	| model |
	model := MAFileModel new
		mimetype: 'image/png';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self assert: model isImage.
	self deny: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeText
	| model |
	model := MAFileModel new
		mimetype: 'text/xml';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self assert: model isText.
	self deny: model isVideo.! !

!MAFileModelTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:15'!
testMimetypeVideo
	| model |
	model := MAFileModel new
		mimetype: 'video/mpeg';
		yourself.

	self deny: model isApplication.
	self deny: model isAudio.
	self deny: model isImage.
	self deny: model isText.
	self assert: model isVideo.! !

TestCase subclass: #MAObjectTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Core'!

MAObjectTest subclass: #MAAccessorTest
	instanceVariableNames: 'accessor value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ true! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
accessor
	^ accessor! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:29'!
instance
	^ accessor! !

!MAAccessorTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:29'!
setUp
	super setUp.
	accessor := self accessorInstance.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self subclassResponsibility.! !

!MAAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAAccessor! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 7/7/2005 15:39'!
testRead
	self accessor canRead
		ifTrue: [ self error: 'Missing read test.' ].! !

!MAAccessorTest methodsFor: 'testing' stamp: 'lr 7/7/2005 15:39'!
testWrite
	self accessor canWrite
		ifTrue: [ self error: 'Missing write test.' ].! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value
	^ value! !

!MAAccessorTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:29'!
value: anObject
	value := anObject! !

MAAccessorTest subclass: #MABlockAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MABlockAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
accessorInstance
	^ self testedClass
		read: [ :model | model value ]
		write: [ :model :object | model value: object ].! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self assert: self instance canRead.
	self instance readBlock: nil.
	self deny: self instance canRead.! !

!MABlockAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self assert: self instance canWrite.
	self instance writeBlock: nil.
	self deny: self instance canWrite.! !

!MABlockAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MABlockAccessor! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testReadBlock
	self accessor readBlock: [ :model |
		self assert: model = self. 123 ].
	self assert: (self accessor read: self) = 123.! !

!MABlockAccessorTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:29'!
testReferenceStream
	"The class BlockContext is not serializeable, ignore this test."! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MABlockAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWriteBlock
	self accessor writeBlock: [ :model :object |
		self assert: model = self.
		self assert: object = 123 ].
	self accessor write: 123 to: self.! !

MAAccessorTest subclass: #MACascadeAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MACascadeAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 9/9/2005 11:33'!
accessorInstance
	^ self testedClass selectors: #( holder contents value ).! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
holder
	^ ValueHolder new 
		contents: self;
		yourself.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:17'!
testAccessor
	self accessor accessor: self.
	self assert: self accessor accessor = self.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanRead
	self assert: self accessor canRead.
	self accessor next next readSelector: nil.
	self deny: self accessor canRead.! !

!MACascadeAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:29'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor next next writeSelector: nil.
	self deny: self accessor canWrite.! !

!MACascadeAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MACascadeAccessor! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testKind
	self assert: (self accessor isKindOf: MACascadeAccessor).
	self assert: (self accessor accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next isKindOf: MACascadeAccessor).
	self assert: (self accessor next accessor isKindOf: MASelectorAccessor).
	self assert: (self accessor next next isKindOf: MASelectorAccessor).! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:17'!
testNext
	self accessor next: self.
	self assert: self accessor next = self.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testSelector
	self assert: self accessor accessor selector = #holder.
	self assert: self accessor next accessor selector = #contents.
	self assert: self accessor next next selector = #value.! !

!MACascadeAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:29'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAAccessorTest subclass: #MAContainerAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAContainerAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
accessorInstance
	^ self testedClass new.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testCanRead
	self assert: self accessor canRead.! !

!MAContainerAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testCanWrite
	self deny: self accessor canWrite.! !

!MAContainerAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAContainerAccessor! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testRead
	self assert: (self accessor read: 123) = 123.! !

!MAContainerAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:30'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

MAAccessorTest subclass: #MADictionaryAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MADictionaryAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MADictionaryAccessorTest methodsFor: 'private' stamp: 'lr 10/3/2005 23:11'!
accessorInstance
	^ self testedClass key: #value.! !

!MADictionaryAccessorTest methodsFor: 'accessing' stamp: 'lr 10/3/2005 23:13'!
at: aKey ifAbsent: aBlock
	^ aKey = #value
		ifTrue: [ value ]
		ifFalse: [ aBlock value ]! !

!MADictionaryAccessorTest methodsFor: 'accessing' stamp: 'lr 10/10/2005 09:06'!
at: aKey put: aValue
	aKey ~= #value ifTrue: [ self fail ].
	^ value := aValue.! !

!MADictionaryAccessorTest methodsFor: 'testing-testing' stamp: 'lr 10/3/2005 23:11'!
testCanRead
	self assert: self accessor canRead.! !

!MADictionaryAccessorTest methodsFor: 'testing-testing' stamp: 'lr 10/3/2005 23:11'!
testCanWrite
	self assert: self accessor canWrite.! !

!MADictionaryAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MADictionaryAccessor! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:16'!
testKey
	self accessor key: #other.
	self assert: self accessor key = #other.! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:19'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.

	self accessor key: #other.
	self assert: (self accessor read: self) isNil.! !

!MADictionaryAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:11'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAAccessorTest subclass: #MANullAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MANullAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
accessorInstance
	^ self testedClass new.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:31'!
testCanRead
	self deny: self accessor canRead.! !

!MANullAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:31'!
testCanWrite
	self deny: self accessor canWrite.! !

!MANullAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MANullAccessor! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testRead
	self 
		should: [ self accessor read: self ]
		raise: Error.! !

!MANullAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:31'!
testWrite
	self 	
		should: [ self accessor write: 123 to: self ] 
		raise: Error.
	self assert: self value isNil.! !

MAAccessorTest subclass: #MASelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

MASelectorAccessorTest subclass: #MAAutoSelectorAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAAutoSelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAAutoSelectorAccessorTest methodsFor: 'running' stamp: 'lr 10/3/2005 23:24'!
tearDown
	super tearDown.
	
	" remove methods and category "
	(self class organization listAtCategoryNamed: #accessing)
		do: [ :each | self class removeSelector: each ].
	self class organization removeCategory: #accessing.

	" remove instance variables "
	self class instVarNames 
		do: [ :each | self class removeInstVarName: each ].
	
	! !

!MAAutoSelectorAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:28'!
testBuilding
	accessor := self testedClass selector: #foo.
	self assert: (accessor write: 123 to: self; read: self) = 123.
	
	accessor := self testedClass selector: #bar.
	self assert: (accessor read: self) isNil.
	self assert: (accessor write: 321 to: self; read: self) = 321.
	
	self assert: (self respondsTo: #foo); assert: (self respondsTo: #foo:). 
	self assert: (self respondsTo: #bar); assert: (self respondsTo: #bar:).
	self assert: (self perform: #foo) = 123; assert: (self perform: #bar) = 321.! !

!MAAutoSelectorAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAAutoSelectorAccessor! !

!MASelectorAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
accessorInstance
	^ self testedClass selector: #value.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:32'!
testCanRead
	self assert: self accessor canRead.
	self accessor readSelector: nil.
	self deny: self accessor canRead.! !

!MASelectorAccessorTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:32'!
testCanWrite
	self assert: self accessor canWrite.
	self accessor writeSelector: nil.
	self deny: self accessor canWrite.! !

!MASelectorAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MASelectorAccessor! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testReadSelector
	self accessor readSelector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #value:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testSelector
	self accessor selector: #contents.
	
	self assert: self accessor selector = #contents.
	self assert: self accessor readSelector = #contents.
	self assert: self accessor writeSelector = #contents:.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

!MASelectorAccessorTest methodsFor: 'testing' stamp: 'lr 5/8/2005 20:32'!
testWriteSelector
	self accessor writeSelector: #contents:.
	
	self assert: self accessor selector = #value.
	self assert: self accessor readSelector = #value.
	self assert: self accessor writeSelector = #contents:.! !

MAAccessorTest subclass: #MAVariableAccessorTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Accessor'!

!MAVariableAccessorTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 5/9/2005 13:48'!
accessorInstance
	^ self testedClass name: 'value'.! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 6/2/2005 10:52'!
testCanRead
	self assert: self accessor canRead.! !

!MAVariableAccessorTest methodsFor: 'testing-testing' stamp: 'lr 6/2/2005 10:52'!
testCanWrite
	self assert: self accessor canWrite.! !

!MAVariableAccessorTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAVariableAccessor! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 10/3/2005 23:15'!
testName
	self accessor name: 'other'.
	self assert: self accessor name = 'other'.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:48'!
testRead
	self value: 123.
	self assert: (self accessor read: self) = 123.
	
	self value: '12'.
	self assert: (self accessor read: self) = '12'.! !

!MAVariableAccessorTest methodsFor: 'testing' stamp: 'lr 5/9/2005 13:49'!
testWrite
	self accessor write: 123 to: self.
	self assert: self value = 123.
	
	self accessor write: '123' to: self.
	self assert: self value = '123'.! !

MAObjectTest subclass: #MADescriptionTest
	instanceVariableNames: 'description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MADescriptionTest subclass: #MAContainerTest
	instanceVariableNames: 'child1 child2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAContainerTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
child1
	child1 isNil
		ifTrue: [ child1 := MAStringDescription selector: #child1 label: 'child1' priority: 1 ].
	^ child1.! !

!MAContainerTest methodsFor: 'accessing' stamp: 'lr 7/7/2005 15:08'!
child2
	child2 isNil
		ifTrue: [ child2 := MAStringDescription selector: #child2 label: 'child2' priority: 2 ].
	^ child2.! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 5/8/2005 20:30'!
testAdd
	self description add: self child1.
	self assert: (self description size = 1).
	self assert: (self description includes: self child1).
	
	self description add: self child2.
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-adding' stamp: 'lr 5/8/2005 20:30'!
testAddAll
	self description addAll: (Array 
		with: self child1 
		with: self child2).
	
	self assert: (self description size = 2).
	self assert: (self description includes: self child1).
	self assert: (self description includes: self child2).! !

!MAContainerTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self assert: self description asContainer = self description.
	self assert: self description asContainer == self description.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testChildren
	self assert: self description children isCollection.
	self assert: self description children isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:08'!
testCollect
	| collected |
	self description add: self child1; add: self child2.
	collected := self description collect: [ :each | each ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | each copy ].
	self assert: self description = collected.
	self deny: self description == collected.
	
	collected := self description collect: [ :each | 
		each copy
			accessor: (MASelectorAccessor selector: #foo);
			yourself ].
	self deny: self description = collected.
	self deny: self description == collected.


! !

!MAContainerTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:30'!
testConcatenation
	| concatenate |
	concatenate := self description , self child1.
	self assert: concatenate size = 1.
	self assert: concatenate children first = self child1.
	
	concatenate := concatenate , self child2 asContainer.
	self assert: concatenate size = 2.
	self assert: concatenate children first = self child1.
	self assert: concatenate children second = self child2.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopy
	self description add: self child1; add: self child2.
	super testCopy.
	
	self deny: self description copy children == self description children.
	self assert: self description copy children first = self description children first.
	self assert: self description copy children second = self description children second.! !

!MAContainerTest methodsFor: 'testing-copying' stamp: 'lr 5/8/2005 20:30'!
testCopyFromTo
	| copied |
	self description add: self child1; add: self child2.
	copied := self description copyFrom: 1 to: 1.
	
	self assert: copied ~= self description.
	self assert: copied size = 1.
	self assert: copied children first = self description children first.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetect
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ]) = self child1.
	self should: [ self description 
		detect: [ :each | self child2 = each ] ] raise: Error.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDetectIfNone
	self description add: self child1.
	self assert: (self description 
		detect: [ :each | self child1 = each ] 
		ifNone: [ 123 ]) = self child1.
	self assert: (self description 
		detect: [ :each | self child2 = each ] 
		ifNone: [ 123 ]) = 123.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDo
	| collection |
	collection := self description class defaultCollection.
	self description add: self child1; add: self child2.
	self description do: [ :each | collection add: each ].
	self assert: (self description children hasEqualElements: collection).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testDoSepratedBy
	| collection |
	collection := OrderedCollection new.
	self description add: self child1; add: self child2.
	self description 
		do: [ :each | collection add: each ]
		separatedBy: [ collection add: nil ].
	self assert: collection size = 3.
	self assert: collection first = self child1.
	self assert: collection second isNil.
	self assert: collection third = self child2.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testEmpty
	self assert: self description isEmpty.
	self description add: self child1.
	self deny: self description isEmpty.! !

!MAContainerTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAContainer! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	super testHasChildren.
	self description add: self child1.
	self assert: self description hasChildren.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIncludes
	self deny: (self description includes: self child1).
	self description add: self child1.
	self assert: (self description includes: self child1).! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 5/8/2005 20:30'!
testInjectInto
	self description add: self child1; add: self child2.
	self assert: (self description 
		inject: 'start'
		into: [ :result :each | result , ' ' , each label ]) = 'start child1 child2'.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self assert: self description isContainer.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 10/17/2005 09:53'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveDown: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.! !

!MAContainerTest methodsFor: 'testing-moving' stamp: 'lr 10/17/2005 09:54'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	
	self description moveUp: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.! !

!MAContainerTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testNotEmpty
	self deny: self description notEmpty.
	self description add: self child1.
	self assert: self description notEmpty.! !

!MAContainerTest methodsFor: 'testing-indentity' stamp: 'lr 5/8/2005 20:30'!
testReferenceStream
	" self debug: #testReferenceStream "
	
	| object |
	self description add: self child1; add: self child2.
	object := super testReferenceStream.
	
	self assert: object children first = self child1.
	self deny: object children first == self child1.
	
	self assert: object children second = self child2.
	self deny: object children second == self child2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:14'!
testReject
	| rejected |
	self description add: self child1; add: self child2.
	
	rejected := self description reject: [ :each | false ].
	self assert: self description = rejected.

	rejected := self description reject: [ :each | true ].
	self assert: rejected isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemove
	self description add: self child1; add: self child2.

	self description remove: self child1.
	self assert: self description size = 1.
	self deny: (self description includes: self child1).
	self assert: (self description includes: self child2).

	self description remove: self child2.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-removing' stamp: 'lr 5/8/2005 20:30'!
testRemoveAll
	self description add: self child1; add: self child2.

	self description removeAll.
	self assert: self description isEmpty.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 7/7/2005 15:15'!
testSelect
	| selected |
	self description add: self child1; add: self child2.
	
	selected := self description select: [ :each | true ].
	self assert: self description = selected.
	
	selected := self description select: [ :each | false ].
	self assert: selected isEmpty.! !

!MAContainerTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testSize
	self assert: self description size isZero.
	self description add: self child1.
	self assert: self description size = 1.
	self description add: self child2.
	self assert: self description size = 2.! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 10/13/2005 19:11'!
testWithDo
	self description add: self child1; add: self child2.
	self description with: self description children 
		do: [ :first :second | self assert: first = second ].! !

!MAContainerTest methodsFor: 'testing-enumerating' stamp: 'lr 10/13/2005 19:11'!
testWithIndexDo
	self description add: self child1; add: self child2.
	self description withIndexDo: [ :each :index | 
		index = 1
			ifTrue: [ self assert: self child1 = each ]
			ifFalse: [
				index = 2
					ifTrue: [ self assert: self child2 = each ]
					ifFalse: [ self fail ] ] ].! !

MAContainerTest subclass: #MAPriorityContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPriorityContainerTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAPriorityContainerTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAPriorityContainer! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:31'!
testMoveDown
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child2 priority = 2.
	
	self description moveDown: self child2; moveDown: self child2.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child2 priority = 0.! !

!MAPriorityContainerTest methodsFor: 'testing-moving' stamp: 'lr 5/8/2005 20:31'!
testMoveUp
	self description add: self child1; add: self child2.
	self assert: self description children first = self child1.
	self assert: self description children second = self child2.
	self assert: self child1 priority = 1.
	
	self description moveUp: self child1; moveUp: self child1.
	self assert: self description children first = self child2.
	self assert: self description children second = self child1.
	self assert: self child1 priority = 3.! !

MAContainerTest subclass: #MAReportContainerTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAReportContainerTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAReportContainerTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAReportContainer! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ true! !

!MADescriptionTest class methodsFor: 'testing' stamp: 'lr 5/8/2005 20:33'!
shouldInheritSelectors
	^ true! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
description
	^ description! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 10/13/2005 19:31'!
descriptionInstance
	^ self testedClass new
		accessor: MANullAccessor new;
		yourself.! !

!MADescriptionTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:30'!
instance
	^ description! !

!MADescriptionTest methodsFor: 'running' stamp: 'lr 9/23/2005 20:10'!
setUp
	super setUp.
	description := self descriptionInstance.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 19:03'!
testAccessor
	self description accessor: (MASelectorAccessor selector: #foo).
	self assert: self description accessor selector = #foo.! !

!MADescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:30'!
testAsContainer
	self subclassResponsibility.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testComment
	self description comment: 'bar'.
	self assert: self description comment = 'bar'.! !

!MADescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:25'!
testCopyAccessor
	self assert: self description copy accessor = self description accessor.
	self deny: self description copy accessor == self description accessor.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testDictionaryKey
	| dictionary |
	dictionary := Dictionary new.
	
	dictionary at: self instance put: 1.
	self assert: (dictionary at: self instance) = 1.
	
	dictionary at: self instance put: 2.
	self assert: (dictionary at: self instance) = 2.! !

!MADescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MADescription! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasChildren
	self deny: self description hasChildren.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasComment
	self description comment: nil.
	self deny: self description hasComment.
	
	self description comment: ''.
	self deny: self description hasComment.
	
	self description comment: 'comment'.
	self assert:  self description hasComment.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testHasLabel
	self description label: nil.
	self deny: self description hasLabel.
	
	self description label: ''.
	self deny: self description hasLabel.
	
	self description label: 'label'.
	self assert:  self description hasLabel.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 5/8/2005 20:30'!
testIsContainer
	self deny: self description isContainer.! !

!MADescriptionTest methodsFor: 'testing-testing' stamp: 'lr 9/15/2005 12:58'!
testIsDescription
	self assert: self description isDescription.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testLabel
	self description label: 'foo'.
	self assert: self description label = 'foo'.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 10/13/2005 17:51'!
testPersistent
	self description beEphemeral.
	self deny: self description persistent.
	self deny: self description isPersistent.
	
	self description bePersistent.
	self assert: self description persistent.
	self assert: self description isPersistent.! !

!MADescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:30'!
testPriority
	self description priority: 123.
	self assert: self description priority = 123.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 10/13/2005 17:54'!
testReadonly
	self description beReadonly.
	self assert: self description readonly.
	self assert: self description isReadonly.
	
	self description beWriteable.
	self deny: self description readonly.
	self deny: self description isReadonly.! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testRequired
	self description beRequired.
	self assert: self description required.
	self assert: self description isRequired.
	
	self description beOptional.
	self deny: self description required.
	self deny: self description isRequired.! !

!MADescriptionTest methodsFor: 'testing-identity' stamp: 'lr 5/8/2005 20:30'!
testSetElement
	| set |
	set := Set new.
	
	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).

	set add: self instance.
	self assert: set size = 1.
	self assert: (set includes: self instance).! !

!MADescriptionTest methodsFor: 'testing-actions' stamp: 'lr 5/8/2005 20:30'!
testVisible
	self description beHidden.
	self deny: self description visible.
	self deny: self description isVisible.
	
	self description beVisible.
	self assert: self description visible.
	self assert: self description isVisible.! !

MADescriptionTest subclass: #MAElementDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAElementDescriptionTest subclass: #MABooleanDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MABooleanDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:29'!
includedInstance
	^ true! !

!MABooleanDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MABooleanDescription! !

MAElementDescriptionTest subclass: #MAClassDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAClassDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAClassDescriptionTest methodsFor: 'private' stamp: 'lr 9/15/2005 11:28'!
includedInstance
	^ String! !

!MAClassDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAClassDescription! !

MAElementDescriptionTest subclass: #MAColorDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAColorDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 7/7/2005 15:44'!
includedInstance
	^ Color blue.! !

!MAColorDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAColorDescription! !

!MAElementDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ true! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
emptyInstance
	^ String new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
includedInstance
	self subclassResponsibility! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 10/13/2005 16:58'!
includedInstanceString
	^ MAStringWriter write: self includedInstance description: self descriptionInstance.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ Object new! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
nullInstance
	^ nil! !

!MAElementDescriptionTest methodsFor: 'testing-converting' stamp: 'lr 5/8/2005 20:31'!
testAsContainer
	self assert: (self description asContainer size) = 1.
	self assert: (self description asContainer includes: self description).! !

!MAElementDescriptionTest methodsFor: 'testing-operators' stamp: 'lr 5/8/2005 20:31'!
testConcatenation
	| child1 child2 concatenate |
	child1 := self description copy.
	child2 := self description copy.
	
	concatenate := child1 , child2.
	self assert: concatenate size = 2.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child2.
	
	concatenate := child1 , concatenate.
	self assert: concatenate size = 3.
	self assert: concatenate children first = child1.
	self assert: concatenate children second = child1.
	self assert: concatenate children third = child2.! !

!MAElementDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:19'!
testCopy
	super testCopy.
	self assert: self description copy default = self description default.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testDefault
	self description default: self includedInstance.
	self assert: self description default = self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAElementDescription! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/13/2005 18:09'!
testFromString
	self assert: (self description 
		fromString: self includedInstanceString)
			= self includedInstance.
	self assert: (self description 
		fromString: self includedInstanceString
		reader: self description stringReader)
			= self includedInstance.
	self assert: (self description 
		fromString: self includedInstanceString
		reader: self description stringReader new)
			= self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/13/2005 18:55'!
testFromStringNull
	self assert: (self description 
		fromString: self emptyInstance) isNil.
	self assert: (self description 
		fromString: self emptyInstance
		reader: self description stringReader) isNil.
	self assert: (self description 
		fromString: self emptyInstance
		reader: self description stringReader new) isNil.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 5/8/2005 20:31'!
testKind
	self assert: (self includedInstance isKindOf: self description kind).! !

!MAElementDescriptionTest methodsFor: 'testing-testing' stamp: 'lr 9/23/2005 20:43'!
testSatisfied
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self nullInstance).
	self deny: (self description isSatisfiedBy: self invalidInstance).! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 17:55'!
testStringReader
	| object |
	self description stringReader: (object := MAStringReader new).
	self assert: self description stringReader = object.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/13/2005 17:20'!
testStringWriter
	| object |
	self description stringWriter: (object := MAStringWriter new).
	self assert: self description stringWriter = object.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/13/2005 18:08'!
testToString
	self assert: (self description 
		toString: self includedInstance) 
			= self includedInstanceString.
	self assert: (self description 
		toString: self includedInstance 
		writer: self description stringWriter) 
			= self includedInstanceString.
	self assert: (self description 
		toString: self includedInstance 
		writer: self description stringWriter new) 
			= self includedInstanceString.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:04'!
testToStringFromString
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance)) 
				= self includedInstance.
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance
			writer: self description stringWriter)
		reader: self description stringReader) 
				= self includedInstance.
	self assert: (self description 
		fromString: (self description 
			toString: self includedInstance
			writer: self description stringWriter new)
		reader: self description stringReader new) 
				= self includedInstance.! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/13/2005 18:08'!
testToStringNull
	self assert: (self description 
		toString: self nullInstance) 
			= self description undefined.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter) 
			= self description undefined.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter new) 
			= self description undefined.
	! !

!MAElementDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/13/2005 18:07'!
testToStringUndefined
	self description undefined: 'n/a'.
	self assert: (self description 
		toString: self nullInstance) 
			= 'n/a'.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter) 
			= 'n/a'.
	self assert: (self description 
		toString: self nullInstance 
		writer: self description stringWriter new) 
			= 'n/a'.! !

!MAElementDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 9/15/2005 10:39'!
testUndefined
	self description undefined: 'nop'.
	self assert: self description undefined = 'nop'.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 17:28'!
testValidate
	self description beRequired.
	self
		shouldnt: [ self description validate: self includedInstance ]
		raise: MAValidationError.
	self
		should: [ self description validate: self invalidInstance ]
		raise: MAKindError.
	self
		should: [ self description validate: self nullInstance ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 16:02'!
testValidateConditions
	self description 
		addCondition: [ :value | value = self includedInstance ] 
		labelled: 'included instance test'.
	self 
		shouldnt: [ self description validateConditions: self includedInstance ]
		raise: MAConditionError.
	self
		should: [ self description validateConditions: self invalidInstance ]
		raise: MAConditionError.

	self description 
		addCondition: [ :value | value = self invalidInstance ] 
		labelled: 'invalid instance test'.
	self 
		should: [ self description validateConditions: self includedInstance ]
		raise: MAConditionError.
	self
		should: [ self description validateConditions: self invalidInstance ]
		raise: MAConditionError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 15:48'!
testValidateKind
	self
		should: [ self description validateKind: self invalidInstance ] 
		raise: MAKindError. 
	self
		shouldnt: [ self description validateKind: self includedInstance ] 
		raise: MAKindError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 15:47'!
testValidateRequired
	self description beOptional.
	self 
		shouldnt: [ self description validateRequired: self nullInstance ] 
		raise: MARequiredError. 
	self 
		shouldnt: [ self description validateRequired: self includedInstance ] 
		raise: MARequiredError.

	self description beRequired.
	self 
		should: [ self description validateRequired: self nullInstance ] 
		raise: MARequiredError. 
	self 
		shouldnt: [ self description validateRequired: self includedInstance ]
		raise: MARequiredError.! !

!MAElementDescriptionTest methodsFor: 'testing-validation' stamp: 'lr 10/27/2005 16:10'!
testValidateSpecific
	self 
		shouldnt: [ self description validateSpecific: self includedInstance ]
		raise: MARequiredError.! !

MAElementDescriptionTest subclass: #MAFileDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAFileDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 8/10/2005 19:54'!
includedInstance
	^ MAFileModel new
		contents: 'Lukas Renggli';
		filename: 'author.txt';
		yourself.! !

!MAFileDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAFileDescription! !

!MAFileDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:13'!
testFromString
	self should: [ super testFromString ] raise: Error.! !

!MAFileDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:13'!
testToStringFromString
	self should: [ super testToStringFromString ] raise: Error.! !

MAElementDescriptionTest subclass: #MAMagnitudeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAMagnitudeDescriptionTest subclass: #MADateDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADateDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Date newDay: 11 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
maxInstance
	^ Date newDay: 12 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:21'!
minInstance
	^ Date newDay: 10 month: 6 year: 1980.! !

!MADateDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MADateDescription! !

MAMagnitudeDescriptionTest subclass: #MADurationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MADurationDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ false! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
includedInstance
	^ Duration days: 1 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ Duration days: 2 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ Duration days: 0 hours: 2 minutes: 3 seconds: 4.! !

!MADurationDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MADurationDescription! !

!MAMagnitudeDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ true! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
maxInstance
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:18'!
minInstance
	self subclassResponsibility! !

!MAMagnitudeDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAMagnitudeDescription! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testInfToInf
	self assert: self description min isNil.
	self assert: self description max isNil.
	
	self assert: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testInfToVal
	self description max: self includedInstance.

	self assert: self description min isNil.
	self assert: self description max = self includedInstance.
	
	self assert: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:16'!
testMax
	self description max: self maxInstance.
	self assert: self description max = self maxInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:16'!
testMin
	self description min: self minInstance.
	self assert: self description min = self minInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/19/2005 20:17'!
testMinMax
	self description min: self minInstance max: self maxInstance.
	self assert: self description min = self minInstance.
	self assert: self description max = self maxInstance.! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testValToInf
	self description min: self includedInstance.

	self assert: self description min = self includedInstance.
	self assert: self description max isNil.
	
	self deny: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self assert: (self description isSatisfiedBy: self maxInstance).
	
	! !

!MAMagnitudeDescriptionTest methodsFor: 'testing' stamp: 'lr 10/19/2005 20:17'!
testValToVal
	self description min: self includedInstance.
	self description max: self includedInstance.

	self assert: self description min = self includedInstance.
	self assert: self description max = self includedInstance.
	
	self deny: (self description isSatisfiedBy: self minInstance).
	self assert: (self description isSatisfiedBy: self includedInstance).
	self deny: (self description isSatisfiedBy: self maxInstance).
	
	! !

MAMagnitudeDescriptionTest subclass: #MANumberDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MANumberDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:35'!
includedInstance
	^ 2.7182! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ 3.1415! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ 1.6180! !

!MANumberDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MANumberDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:33'!
includedInstance
	^ Time hour: 11 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ Time hour: 12 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ Time hour: 10 minute: 33 second: 12.! !

!MATimeDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATimeDescription! !

MAMagnitudeDescriptionTest subclass: #MATimeStampDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATimeStampDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 8/25/2005 10:36'!
includedInstance
	^ TimeStamp year: 1980 month: 6 day: 11 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:23'!
maxInstance
	^ TimeStamp year: 1980 month: 6 day: 12 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 10/19/2005 20:22'!
minInstance
	^ TimeStamp year: 1980 month: 6 day: 10 hour: 11 minute: 38 second: 12.! !

!MATimeStampDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATimeStampDescription! !

MAElementDescriptionTest subclass: #MAReferenceDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAReferenceDescriptionTest subclass: #MAOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAOptionDescriptionTest subclass: #MAMultipleOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAMultipleOptionDescriptionTest class methodsFor: 'accessing-default' stamp: 'lr 9/26/2005 09:57'!
defaultUnique
	^ false! !

!MAMultipleOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAMultipleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:24'!
includedInstance
	^ self optionInstances copyFrom: 1 to: 2.! !

!MAMultipleOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 08:24'!
testAllOptionsWithoutNil
	self description beOptional; beSorted; options: #( c b a ).
	self assert: self description allOptions = #( a b c ).

	self description beOptional; beUnsorted; options: #( c b a ).
	self assert: self description allOptions = #( c b a ).! !

!MAMultipleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAMultipleOptionDescription! !

!MAOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MAOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:13'!
optionInstances
	^ Array with: 'foo' with: 'bar' with: 'zork'.! !

!MAOptionDescriptionTest methodsFor: 'running' stamp: 'lr 9/15/2005 11:35'!
setUp
	super setUp.
	self description options: self optionInstances.! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 08:23'!
testAllOptions
	self description beRequired; beSorted; options: #( c b a ).
	self assert: self description allOptions = #( a b c ).
	
	self description beRequired; beUnsorted; options: #( c b a ).
	self assert: self description allOptions = #( c b a ).! !

!MAOptionDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/15/2005 11:34'!
testCopyOptions
	self deny: self description copy options == self description options.
	self assert: self description copy options = self description options.! !

!MAOptionDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAOptionDescription! !

!MAOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 9/15/2005 11:33'!
testOptions
	self description options: #( a b c ).
	self assert: self description options = #( a b c ).! !

!MAOptionDescriptionTest methodsFor: 'testing-properties' stamp: 'lr 9/15/2005 11:37'!
testSorted
	self description beSorted.
	self assert: self description isSorted.
	self assert: self description sorted.
	
	self description beUnsorted.
	self deny: self description isSorted.
	self deny: self description sorted.! !

MAOptionDescriptionTest subclass: #MASingleOptionDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASingleOptionDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MASingleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:13'!
includedInstance
	^ self optionInstances first.! !

!MASingleOptionDescriptionTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 08:23'!
testAllOptionsWithNil
	self description beOptional; beSorted; options: #( c b a ).
	self assert: self description allOptions = #( nil a b c ).

	self description beOptional; beUnsorted; options: #( c b a ).
	self assert: self description allOptions = #( nil c b a ).! !

!MASingleOptionDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MASingleOptionDescription! !

!MAReferenceDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MAReferenceDescriptionTest methodsFor: 'private' stamp: 'lr 9/26/2005 09:21'!
referenceInstance
	^ MAStringDescription null: UUID new.! !

!MAReferenceDescriptionTest methodsFor: 'running' stamp: 'lr 9/15/2005 11:49'!
setUp
	super setUp.
	self description reference: self referenceInstance.! !

!MAReferenceDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 9/26/2005 09:20'!
testCopyReference
	self assert: self description copy reference = self description reference.
	self deny: self description copy reference == self description reference.! !

!MAReferenceDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAReferenceDescription! !

MAReferenceDescriptionTest subclass: #MARelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MARelationDescriptionTest subclass: #MAOneToManyRelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAOneToManyRelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAOneToManyRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:35'!
includedInstance
	^ Array with: self addressInstance1 with: self addressInstance2.! !

!MAOneToManyRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAOneToManyRelationDescription! !

MARelationDescriptionTest subclass: #MAOneToOneRelationDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAOneToOneRelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAOneToOneRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:35'!
includedInstance
	^ self addressInstance1.! !

!MAOneToOneRelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAOneToOneRelationDescription! !

!MARelationDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:42'!
addressInstance1
	^ MAAddressModel new
		street: 'Philosophenweg';
		plz: 3007;
		place: 'Bern';
		canton: 'Bern';
		yourself.! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/27/2005 17:42'!
addressInstance2
	^ MAAddressModel new
		street: 'In der Au';
		plz: 9876;
		place: 'Engi';
		canton: 'Glarus';
		yourself.! !

!MARelationDescriptionTest methodsFor: 'running' stamp: 'lr 10/27/2005 17:33'!
setUp
	super setUp.
	self description classes: (Array with: MAAddressModel).! !

!MARelationDescriptionTest methodsFor: 'testing-copying' stamp: 'lr 10/27/2005 16:58'!
testCopyClasses
	self assert: self description copy classes = self description classes.
	self deny: self description copy classes == self description classes.! !

!MARelationDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MARelationDescription! !

!MARelationDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:10'!
testFromString
	self should: [ super testFromString ] raise: Error. 
! !

!MARelationDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:11'!
testToStringFromString
	self should: [ super testToStringFromString ] raise: Error. 
! !

MAReferenceDescriptionTest subclass: #MATableDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATableDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 10/10/2005 09:43'!
includedInstance
	^ MATableModel rows: 3 columns: 3 contents: #( '1' '2' '3' '2' '4' '6' '3' '6' '9' ). ! !

!MATableDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATableDescription! !

!MATableDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:12'!
testFromString
	self should: [ super testFromString ] raise: Error.! !

!MATableDescriptionTest methodsFor: 'testing-strings' stamp: 'lr 10/28/2005 16:12'!
testToStringFromString
	self should: [ super testToStringFromString ] raise: Error.! !

MAReferenceDescriptionTest subclass: #MATokenDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATokenDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 9/15/2005 11:28'!
includedInstance
	^ #( 'foo' 'bar' )! !

!MATokenDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATokenDescription! !

MAElementDescriptionTest subclass: #MAStringDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

MAStringDescriptionTest subclass: #MAPasswordDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MAPasswordDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAPasswordDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAPasswordDescription! !

!MAStringDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ 'Lukas Renggli'! !

!MAStringDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAStringDescription! !

MAStringDescriptionTest subclass: #MASymbolDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MASymbolDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:32'!
includedInstance
	^ #magritte! !

!MASymbolDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MASymbolDescription! !

MAStringDescriptionTest subclass: #MATextDescriptionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Description'!

!MATextDescriptionTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATextDescriptionTest methodsFor: 'private' stamp: 'lr 9/15/2005 11:27'!
includedInstance
	^ 'Lukas Renggli
Magritte'! !

!MATextDescriptionTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATextDescription! !

MAObjectTest subclass: #MAMementoTest
	instanceVariableNames: 'description memento value'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

MAMementoTest subclass: #MACachedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACachedMementoTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MACachedMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 23:07'!
testCache
	self assert: self memento cache size = self description size.! !

!MACachedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 22:08'!
testCommit
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self value = self nullInstance.
	self assert: self memento hasChanged.
	
	self memento commit.
	self assert: self read = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MACachedMemento! !

!MACachedMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 23:00'!
testRead
	self assert: self read = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self read = self defaultInstance.! !

!MACachedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:11'!
testReset
	self value: self defaultInstance.
	self write: self includedInstance.
	self assert: self memento hasChanged.
	
	self memento reset.
	self assert: self read = self defaultInstance.
	self assert: self value = self defaultInstance.
	self deny: self memento hasChanged.! !

!MACachedMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 23:01'!
testWrite
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self value = self nullInstance.
	
	self write: self defaultInstance.
	self assert: self read = self defaultInstance.
	self assert: self value = self nullInstance
! !

MACachedMementoTest subclass: #MACheckedMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MACheckedMementoTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testConflictCommit
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self deny: self memento hasConflict.
	
	self value: self otherInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self assert: self memento hasConflict.
	
	self memento commit.
	self assert: self read = self includedInstance.
	self assert: self value = self includedInstance.
	self deny: self memento hasChanged.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:27'!
testConflictReset
	self write: self includedInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self deny: self memento hasConflict.
	
	self value: self otherInstance.
	self assert: self read = self includedInstance.
	self assert: self memento hasChanged.
	self assert: self memento hasConflict.
	
	self memento reset.
	self assert: self read = self otherInstance.
	self assert: self value = self otherInstance.
	self deny: self memento hasChanged.
	self deny: self memento hasConflict.! !

!MACheckedMementoTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MACheckedMemento! !

!MACheckedMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 23:07'!
testOriginal
	self assert: self memento original size = self description size.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testValidateConflictCommit
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.
	
	self value: self otherInstance.
	self should: [ self memento validate ] raise: MAValidationError.
	
	self memento commit.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MACheckedMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:26'!
testValidateConflictReset
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.
	
	self value: self otherInstance.
	self should: [ self memento validate ] raise: MAValidationError.
	
	self memento reset.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:51'!
defaultInstance
	^ 'Lukas Renggli'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 21:24'!
description
	^ description! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:51'!
descriptionInstance
	^ MAContainer with: ((MAStringDescription selector: #value)
		default: self defaultInstance;
		yourself).! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 23:05'!
descriptionValue
	^ self description children first.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 23:43'!
includedInstance
	^ 'Rene Magritte'! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
invalidInstance
	^ 31415! !

!MAMementoTest methodsFor: 'accessing' stamp: 'lr 9/20/2005 21:24'!
memento
	^ memento! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 21:23'!
mementoInstance
	^ self testedClass model: self modelInstance.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 21:03'!
modelInstance 
	^ self! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 22:02'!
nullInstance
	^ nil! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 9/20/2005 23:43'!
otherInstance
	^ 'Ursula Freitag'! !

!MAMementoTest methodsFor: 'accessing-memento' stamp: 'lr 9/20/2005 23:06'!
read
	^ self memento readUsing: self descriptionValue.! !

!MAMementoTest methodsFor: 'running' stamp: 'lr 9/20/2005 21:23'!
setUp
	super setUp.
	description := self descriptionInstance.
	memento := self mementoInstance.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:08'!
testCommit
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 21:27'!
testDescription
	self assert: self memento description = self description.
	self assert: self memento description = self descriptionInstance.! !

!MAMementoTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAMemento! !

!MAMementoTest methodsFor: 'testing-accessing' stamp: 'lr 9/20/2005 21:17'!
testModel
	self assert: self memento model = self modelInstance.! !

!MAMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testRead
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:08'!
testReset
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateIncluded
	self write: self includedInstance.
	self shouldnt: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateInvalid
	self write: self invalidInstance.
	self should: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/21/2005 07:28'!
testValidateRequired
	self descriptionValue beRequired.
	
	self write: self nullInstance.
	self should: [ self memento validate ] raise: MAValidationError.! !

!MAMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testWrite
	self subclassResponsibility.! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value
	^ value! !

!MAMementoTest methodsFor: 'accessing-model' stamp: 'lr 5/8/2005 20:31'!
value: anObject
	value := anObject! !

!MAMementoTest methodsFor: 'accessing-memento' stamp: 'lr 9/20/2005 23:06'!
write: anObject
	self memento write: anObject using: self descriptionValue.! !

MAMementoTest subclass: #MAStraitMementoTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Memento'!

!MAStraitMementoTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:20'!
testCommit
	self write: self includedInstance.
	self assert: self value = self includedInstance.
	self assert: self read = self includedInstance.
	
	self memento commit.
	self assert: self value = self includedInstance.
	self assert: self read = self includedInstance.
! !

!MAStraitMementoTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAStraitMemento! !

!MAStraitMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:54'!
testRead
	self assert: self read = self defaultInstance.
	
	self value: self includedInstance.
	self assert: self read = self includedInstance.
	
	self value: self defaultInstance.
	self assert: self read = self defaultInstance.! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:19'!
testReset
	self write: self includedInstance.
	self memento reset.
	self assert: self read = self includedInstance.! !

!MAStraitMementoTest methodsFor: 'testing-actions' stamp: 'lr 9/20/2005 23:52'!
testValidateRequired! !

!MAStraitMementoTest methodsFor: 'testing-basic' stamp: 'lr 9/20/2005 22:59'!
testWrite
	self write: self includedInstance.
	self assert: self value = self includedInstance.
	
	self write: self defaultInstance.
	self assert: self value = self defaultInstance.
	
	self write: self nullInstance.
	self assert: self value = self nullInstance.! !

!MAObjectTest class methodsFor: 'building' stamp: 'lr 10/19/2005 20:33'!
buildTestClassFor: aClass
	" self buildTestClassFor: MAObject "

	| thisName thisClass thisCategory parentClass |
	thisName := (aClass name , 'Test') asSymbol.
	(thisName beginsWith: 'MA') 
		ifFalse: [ ^ self ].
	thisClass := MACompatibility classNamed: thisName.
	thisCategory := 'Magritte-Tests-' , (aClass category copyAfterLast: $-).
	parentClass := self = thisClass
		ifTrue: [ self superclass ]
		ifFalse: [ Smalltalk classNamed: (aClass superclass name , 'Test') asSymbol ].
	thisClass := parentClass 
		subclass: thisName
		instanceVariableNames: (thisClass isNil 
			ifFalse: [ thisClass instanceVariablesString ]
			ifTrue: [ String new ])
		classVariableNames: ''
		poolDictionaries: ''
		category: thisCategory.
	thisClass compile: 'testedClass
	^ ' , aClass name classified: #private.
	thisClass class compile: 'isAbstract
	^ ' , aClass isAbstract asString classified: #testing.
	thisClass subclasses do: [ :each | 
		(aClass subclasses includes: each basicNew testedClass)
			ifFalse: [ Transcript show: each name; show: ' is not used anymore.' ] ].
	aClass subclassesDo: [ :each | self buildTestClassFor: each ].! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:47'!
isAbstract
	^ true! !

!MAObjectTest class methodsFor: 'testing' stamp: 'lr 9/23/2005 19:32'!
shouldInheritSelectors
	^ true! !

!MAObjectTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	self subclassResponsibility.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:24'!
testCopy
	self assert: self instance = self instance copy.
	self deny: self instance == self instance copy.! !

!MAObjectTest methodsFor: 'testing-copying' stamp: 'lr 9/23/2005 20:24'!
testCopyProperties
	self assert: self instance properties = self instance copy properties.
	self deny: self instance properties == self instance copy properties.! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 9/15/2005 10:20'!
testEqual
	self assert: self instance = self instance.
	self assert: self instance = self instance copy.
	self assert: self instance copy = self instance.
	
	self deny: self instance = 123.
	self deny: self instance = String new.! !

!MAObjectTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:47'!
testedClass
	^ MAObject! !

!MAObjectTest methodsFor: 'testing-comparing' stamp: 'lr 9/15/2005 10:21'!
testHash
	self assert: self instance hash isInteger.
	self assert: self instance hash = self instance hash.
	self assert: self instance hash = self instance copy hash.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 9/15/2005 10:28'!
testProperties
	self assert: self instance properties notNil.
	self instance instVarNamed: 'properties' put: nil.
	
	self instance propertyAt: #foo put: #bar.
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsent: [ nil ].
	self instance instVarNamed: 'properties' put: nil.

	self instance propertyAt: #foo ifAbsentPut: [ #bar ].
	self instance instVarNamed: 'properties' put: nil.
	
	self instance hasProperty: #foo.
	self instance instVarNamed: 'properties' put: nil.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAt
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	self should: [ self instance propertyAt: #bar ] raise: Error.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsent
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsent: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #bar ifAbsent: [ 'baz' ]) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtIfAbsentPut
	self assert: (self instance propertyAt: #foo put: 'bar') = 'bar'.
	self assert: (self instance propertyAt: #foo ifAbsentPut: [ 'baz' ]) = 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self assert: (self instance propertyAt: #bar ifAbsentPut: [ 'baz' ]) = 'baz'.
	self assert: (self instance propertyAt: #bar) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 5/8/2005 20:31'!
testPropertiesAtPut
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance propertyAt: #foo) = 'bar'.
	
	self instance propertyAt: #foo put: 'baz'.
	self assert: (self instance propertyAt: #foo) = 'baz'.! !

!MAObjectTest methodsFor: 'testing-properties' stamp: 'lr 7/7/2005 14:50'!
testPropertiesHas
	self deny: (self instance hasProperty: #foo).
	self instance propertyAt: #foo put: 'bar'.
	self assert: (self instance hasProperty: #foo).
	self deny: (self instance hasProperty: #bar).! !

!MAObjectTest methodsFor: 'testing-identity' stamp: 'lr 10/13/2005 18:41'!
testReferenceStream
	" This is an unfortunately non-portable test-method: the idea of this test is that every object should be serializeable and after restoring it, the objects should be still equal. "

	| output input object |
	
	" every instance should be serializeable "
	output := MACompatibility referenceStream: ByteArray new writeStream.
	output nextPut: self instance.
	output close.
	
	" read back the serialized instance "
	input := MACompatibility referenceStream: output contents readStream.
	object := input next.
	
	" different object reference, but equal object "
	self deny: self instance == object.
	self assert: self instance = object.
	
	" return the read in object (for addinal checks in subclasses) "
	^ object.! !

!MAObjectTest methodsFor: 'testing' stamp: 'lr 10/20/2005 11:53'!
testSanity
	"If this test case fails, there is something wrong with the setup of the test-case."
	
	self
		assert: self testedClass isAbstract not
		description: 'Unable to test abstract class.'.
	self 
		assert: self instance class = self testedClass 
		description: 'Invalid test instance.'.! !

MAObjectTest subclass: #MARelationTest
	instanceVariableNames: 'relation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MARelationTest subclass: #MABasicRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MABasicRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MABasicRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MABasicRelation! !

MABasicRelationTest subclass: #MAConstantRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAConstantRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MAConstantRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAConstantRelation! !

!MAConstantRelationTest methodsFor: 'testing' stamp: 'lr 10/27/2005 14:43'!
testIsConstant
	self assert: self relation isConstant.! !

MAConstantRelationTest subclass: #MAFalseRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAFalseRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAFalseRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:47'!
testAll
	self assert: (self relation & self true) = self false.
	self assert: (self relation & self false) = self false.! !

!MAFalseRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:47'!
testAny
	self assert: (self relation | self true) = self true.
	self assert: (self relation | self false) = self false.! !

!MAFalseRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAFalseRelation! !

!MAFalseRelationTest methodsFor: 'testing' stamp: 'lr 10/27/2005 14:39'!
testFalse
	self fails: self relation.! !

!MAFalseRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:45'!
testNot
	self assert: self relation not = self true.! !

MAConstantRelationTest subclass: #MATrueRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MATrueRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MATrueRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:47'!
testAll
	self assert: (self relation & self true) = self true.
	self assert: (self relation & self false) = self false.! !

!MATrueRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:46'!
testAny
	self assert: (self relation | self true) = self true.
	self assert: (self relation | self false) = self true.! !

!MATrueRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MATrueRelation! !

!MATrueRelationTest methodsFor: 'testing-operators' stamp: 'lr 10/27/2005 14:45'!
testNot
	self assert: self relation not = self false.! !

!MATrueRelationTest methodsFor: 'testing' stamp: 'lr 10/27/2005 14:39'!
testTrue
	self satisfies: self relation.! !

MABasicRelationTest subclass: #MASelectorRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MASelectorRelationTest subclass: #MAAccessorRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAccessorRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAAccessorRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAAccessorRelation! !

MASelectorRelationTest subclass: #MAQueryRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAQueryRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAQueryRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAQueryRelation! !

!MASelectorRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MASelectorRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MASelectorRelation! !

MARelationTest subclass: #MAComposedRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

MAComposedRelationTest subclass: #MAAllRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAllRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:40'!
testAll
	self assert: (self relation & self true) class = MAAllRelation.
	self assert: (self relation & self false) relations first = self false.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:35'!
testBinary
	self satisfies: self true & self true.
	self fails: self true & self false.
	self fails: self false & self true.
	self fails: self false & self false.! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:36'!
testEmpty
	self satisfies: self relation.! !

!MAAllRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAAllRelation! !

!MAAllRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:35'!
testUnary
	self satisfies: self relation & self true.
	self fails: self relation & self false.! !

MAComposedRelationTest subclass: #MAAnyRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MAAnyRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:39'!
testAny
	self assert: (self relation | self true) class = MAAnyRelation.
	self assert: (self relation | self false) relations first = self false.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:36'!
testBinary
	self satisfies: self true | self true.
	self satisfies: self true | self false.
	self satisfies: self false | self true.
	self fails: self false | self false.! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:36'!
testEmpty
	self fails: self relation.! !

!MAAnyRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAAnyRelation! !

!MAAnyRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:36'!
testUnary
	self satisfies: self relation | self true.
	self fails: self relation | self false.! !

!MAComposedRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MAComposedRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MAComposedRelation! !

!MAComposedRelationTest methodsFor: 'testing' stamp: 'lr 10/27/2005 14:29'!
testIsComposed
	self assert: self relation isComposed.! !

MAComposedRelationTest subclass: #MANoneRelationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Relation'!

!MANoneRelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ false! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:37'!
testBinary
	self fails: self true !! self true.
	self fails: self true !! self false.
	self fails: self false !! self true.
	self satisfies: self false !! self false.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:37'!
testEmpty
	self satisfies: self relation.! !

!MANoneRelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MANoneRelation! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:39'!
testNone
	self assert: (self relation !! self true) class = MANoneRelation.
	self assert: (self relation !! self false) relations first = self false.! !

!MANoneRelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:37'!
testUnary
	self fails: self relation !! self true.
	self satisfies: self relation !! self false.! !

!MARelationTest class methodsFor: 'testing' stamp: 'lr 10/29/2005 20:48'!
isAbstract
	^ true! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:31'!
fails: aRelation
	self deny: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 10/27/2005 14:31'!
false
	^ MAFalseRelation new.! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
instance
	^ relation! !

!MARelationTest methodsFor: 'accessing' stamp: 'lr 5/8/2005 20:31'!
relation
	^ relation! !

!MARelationTest methodsFor: 'private' stamp: 'lr 5/8/2005 20:31'!
relationInstance
	^ self testedClass new.! !

!MARelationTest methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:31'!
satisfies: aRelation
	self assert: (aRelation isSatisfiedBy: self).! !

!MARelationTest methodsFor: 'running' stamp: 'lr 5/8/2005 20:31'!
setUp
	super setUp.
	relation := self relationInstance.! !

!MARelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:32'!
testAll
	self assert: (self relation & self true) class = MAAllRelation.
	self assert: (self relation & self false) relations first = self relation.
	self assert: (self relation & self false) relations second = self false.! !

!MARelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:32'!
testAny
	self assert: (self relation | self true) class = MAAnyRelation.
	self assert: (self relation | self false) relations first = self relation.
	self assert: (self relation | self false) relations second = self false.! !

!MARelationTest methodsFor: 'private' stamp: 'lr 10/29/2005 20:48'!
testedClass
	^ MARelation! !

!MARelationTest methodsFor: 'testing-testing' stamp: 'lr 10/27/2005 14:28'!
testIsComposed
	self deny: self relation isComposed.! !

!MARelationTest methodsFor: 'testing-testing' stamp: 'lr 10/27/2005 14:28'!
testIsConstant
	self deny: self relation isConstant.! !

!MARelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:32'!
testNone
	self assert: (self relation !! self true) class = MANoneRelation.
	self assert: (self relation !! self false) relations first = self relation.
	self assert: (self relation !! self false) relations second = self false.! !

!MARelationTest methodsFor: 'testing' stamp: 'lr 10/3/2005 08:31'!
testNot
	self assert: self relation not class = MANoneRelation.
	self assert: self relation not relations first = self relation.! !

!MARelationTest methodsFor: 'constants' stamp: 'lr 10/27/2005 14:31'!
true
	^ MATrueRelation new.! !

TestCase subclass: #MAScaffolderTest
	instanceVariableNames: 'scaffolder'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MAScaffolderTest methodsFor: 'accessing' stamp: 'lr 9/9/2005 11:27'!
descriptions
	^ self scaffolder description children.! !

!MAScaffolderTest methodsFor: 'accessing' stamp: 'lr 9/9/2005 11:25'!
scaffolder
	^ scaffolder! !

!MAScaffolderTest methodsFor: 'running' stamp: 'lr 9/9/2005 11:32'!
setUp
	scaffolder := MAScaffolder new.
	scaffolder description
		add: (MAStringDescription null: UUID new);
		add: (MANumberDescription null: UUID new).
	scaffolder write: 'foo' using: self descriptions first.
	scaffolder write: 123 using: self descriptions second.
	! !

!MAScaffolderTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:31'!
testRead
	self assert: (self scaffolder readUsing: self descriptions first) = 'foo'.
	self assert: (self scaffolder readUsing: self descriptions second) = 123.! !

!MAScaffolderTest methodsFor: 'testing' stamp: 'lr 9/9/2005 11:31'!
testWrite
	self scaffolder write: 'bar' using: self descriptions first.
	self scaffolder write: 321 using: self descriptions second.
	
	self assert: (self scaffolder readUsing: self descriptions first) = 'bar'.
	self assert: (self scaffolder readUsing: self descriptions second) = 321.! !

TestCase subclass: #MATableModelTest
	instanceVariableNames: 'table'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Model'!

!MATableModelTest methodsFor: 'running' stamp: 'lr 10/3/2005 11:23'!
setUp
	table := (MATableModel rows: 3 columns: 4)
		collect: [ :row :col :value | row raisedTo: col ].! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:26'!
testAtAt
	self assert: (table at: 1 at: 1) = 1.
	self assert: (table at: 2 at: 3) = 8.
	self assert: (table at: 3 at: 2) = 9.	
	self assert: (table at: 3 at: 4) = 81.


	! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:26'!
testAtAtAbsent
	self should: [ table at: 0 at: 1 ] raise: Error.
	self should: [ table at: 1 at: 0 ] raise: Error.
	self should: [ table at: 4 at: 4 ] raise: Error.
	self should: [ table at: 3 at: 5 ] raise: Error.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testAtAtPut
	self assert: (table at: 1 at: 1 put: -1) = -1.
	self assert: (table at: 2 at: 3 put: -8) = -8.
	self assert: (table at: 3 at: 2 put: -9) = -9.	
	self assert: (table at: 3 at: 4 put: -81) = -81.

	self assert: (table at: 1 at: 1) = -1.
	self assert: (table at: 2 at: 3) = -8.
	self assert: (table at: 3 at: 2) = -9.	
	self assert: (table at: 3 at: 4) = -81.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:28'!
testAtAtPutAbsent
	self should: [ table at: 0 at: 1 put: 0 ] raise: Error.
	self should: [ table at: 1 at: 0 put: 0 ] raise: Error.
	self should: [ table at: 4 at: 4 put: 0 ] raise: Error.
	self should: [ table at: 3 at: 5 put: 0 ] raise: Error.! !

!MATableModelTest methodsFor: 'testing-enumerating' stamp: 'lr 10/3/2005 11:48'!
testCollect
	table := table collect: [ :row :col :val | row + col + val ].
	table do: [ :row :col :val | self assert: (row raisedTo: col) = (val - row - col) ].! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testContents
	self assert: table contents = #( 1 1 1 1 2 4 8 16 3 9 27 81 ).! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:51'!
testCopy
	self assert: table copy rowCount = table rowCount.
	self assert: table copy columnCount = table columnCount.
	self assert: table copy contents = table contents.
	self deny: table copy contents == table contents.! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:50'!
testCopyEmpty
	self assert: table copyEmpty rowCount = table rowCount.
	self assert: table copyEmpty columnCount = table columnCount.
	self assert: (table copyEmpty contents allSatisfy: [ :each | each isNil ]).! !

!MATableModelTest methodsFor: 'testing-copying' stamp: 'lr 10/3/2005 11:53'!
testCopyRowsColumns
	self assert: (table copyRows: 1 columns: 2) rowCount = 1.
	self assert: (table copyRows: 1 columns: 2) columnCount = 2.
	self assert: (table copyRows: 1 columns: 2) contents = #(1 1).

	self assert: (table copyRows: 4 columns: 3) rowCount = 4.
	self assert: (table copyRows: 4 columns: 3) columnCount = 3.
	self assert: (table copyRows: 4 columns: 3) contents = #(1 1 1 2 4 8 3 9 27 nil nil nil).! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testCoumnCount
	self assert: table columnCount = 4.! !

!MATableModelTest methodsFor: 'testing-enumerating' stamp: 'lr 10/3/2005 11:48'!
testDo
	table do: [ :row :col :val | self assert: (row raisedTo: col) = val ].! !

!MATableModelTest methodsFor: 'testing-comparing' stamp: 'lr 10/3/2005 11:33'!
testEqual
	self assert: table = table.
	self assert: table = table copy.
	self assert: table copy = table.
	self assert: table copy = table copy.

	self deny: table = (table copy at: 1 at: 2 put: 3).
	self deny: table = (table copyRows: 3 columns: 3). 
	self deny: table = (table copyRows: 4 columns: 4). 
	! !

!MATableModelTest methodsFor: 'testing-comparing' stamp: 'lr 10/3/2005 11:32'!
testHash
	self assert: table hash = table hash.
	self assert: table hash = table copy hash.
	self assert: table copy hash = table hash.
	self assert: table copy hash = table copy hash.! !

!MATableModelTest methodsFor: 'testing-accessing' stamp: 'lr 10/3/2005 11:29'!
testRowCount
	self assert: table rowCount = 3.! !

!MATableModelTest methodsFor: 'testing' stamp: 'lr 10/3/2005 11:23'!
testSetup
	self assert: table rowCount = 3.
	self assert: table columnCount = 4.
	self assert: table contents = #( 1 1 1 1 2 4 8 16 3 9 27 81 ).! !

Object subclass: #MAConventionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Magritte-Tests-Utility'!

!MAConventionTests methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:30'!
cleanCategories
	"self new cleanCategories"
	
	self classesDo: [ :class | 
		class organization 
			removeEmptyCategories; 
			sortCategories.
		class class organization 
			removeEmptyCategories; 
			sortCategories ].! !

!MAConventionTests methodsFor: 'utilities' stamp: 'lr 5/8/2005 20:30'!
cleanMethods
	"self new cleanMethods"
	
	| old new |
	self selectorsDo: [ :class :selector |
		old := (class sourceCodeAt: selector)
			asString withBlanksTrimmed readStream.
		new := String streamContents: [ :stream |
			[ old atEnd ] whileFalse: [
				stream nextPutAll: (old upTo: $^ ).
				old atEnd ifFalse: [
					stream nextPutAll: '^ '.
					[ old peek = Character space ]
						whileTrue: [ old next ] ] ] ].
		old = new 
			ifFalse: [ class compile: new ] ].! !

!MAConventionTests methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
decompiledSourceCodeIn: aClass at: aSelector
	| method |
	method := aClass decompile: aSelector.
	method := method decompileString readStream
		nextLine;
		upToEnd.
	^ method withBlanksCondensed.! !

!MAConventionTests methodsFor: 'private' stamp: 'lr 5/8/2005 20:30'!
originalSourceCodeIn: aClass at: aSelector
	| input output |
	input := (aClass sourceCodeAt: aSelector) readStream
		nextLine;
		yourself.
	output := String streamContents: [ :stream |
		[ input atEnd ] whileFalse: [
			stream nextPutAll: (input upTo: $").
			input atEnd 
				ifFalse: [ input upTo: $" ] ] ].
	^ output withBlanksCondensed.! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testAbstractAndDescription
	"Classes not being tagged as abstract, should return a proper description."
	"self debug: #testAbstractAndDescription"

	self subclassesOf: MAObject do: [ :class |
		class isAbstract ifFalse: [
			self 
				deny: class description isNil 
				description: class name , ' should have a proper description.' 
				resumable: true ] ].! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testAbstractAndResponsability
	"Classes being tagged as concrete, shouldn't call #subclassResponsability."
	"self debug: #testAbstractAndResponsability"

	| method |
	self subclassesOf: MAObject do: [ :class |
		class isAbstract ifFalse: [
			class allSelectors do: [ :selector |
				method := class lookupSelector: selector.
				self 
					deny: (method hasLiteral: #subclassResponsibility)
					description: class name , ' is abstract because of #' , selector 
					resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodArguments
	"For readability we do not want more than 5 arguments a method."
	"self debug: #testMethodArguments"

	self selectorsDo: [ :class :selector |
		 self
			deny: selector numArgs > 5
			description: class name , '>>' , selector , ' has too many arguments.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodCompile
	"All methods should be properly compileable."
	"self debug: #testMethodCompile"
	
	self selectorsDo: [ :class :selector | 
		class recompile: selector ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodCurlyBrace
	"For portability we don't want curly braces in our code."
	"self debug: #testMethodCurlyBrace"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#braceStream: 
				#braceWith: 
				#braceWith:with: 
				#braceWith:with:with: 
				#braceWith:with:with:with: 
				#braceWithNone ))
			description: class name , '>>' , selector , ' contains curly braces.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodFullstop
	"Methods other than simple accessors should all end with a fullstop."
	"self debug: #testMethodFullstop"

	| source |
	self selectorsDo: [ :class :selector |
		source := self originalSourceCodeIn: class at: selector.
		self
			assert: (source lineCount <= 1 or: [ source endsWith: '.' ]) 
			description: class name , '>>' , selector , ' doesn''t end with a fullstop.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodHalt
	"Debugging code needs to be removed before deployment."
	"self debug: #testMethodHalt"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#halt
				#halt: 
				#haltIfNil ))
			description: class name , '>>' , selector , ' has got debugging statements.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodInitialize
	"All instance-side implementors of initialize should call super initialize, class side implementers douldn't call super."
	"self debug: #testMethodInitialize"

	| source |
	self selectorsDo: [ :class :selector |
		selector = #initialize ifTrue: [
			source := self originalSourceCodeIn: class at: selector.
			class isMeta 
				ifTrue: [
					self
						deny: ('*super initialize.*' match: source)
						description: class name , '>>' , selector , ' calls super.'
						resumable: true ]
				ifFalse: [
					self
						assert: ('*super initialize.*' match: source)
						description: class name , '>>' , selector , ' doesn''t call super.'
						resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodMaxLines
	"For readability we do not want methods to be short."
	"self debug: #testMethodMaxLines"

	| source |
	self selectorsDo: [ :class :selector |
		source := self decompiledSourceCodeIn: class at: selector.
		self
			assert: (source lineCount <= 16 
				or: [ source size <= 1024 ] 
				or: [ selector beginsWith: #default ])
			description: class name , '>>' , selector , ' is too long.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodPostCopy
	"All implementors of postCopy should call super postCopy."
	"self debug: #testMethodPostCopy"

	| source |
	self selectorsDo: [ :class :selector |
		source := self originalSourceCodeIn: class at: selector.
		selector = #postCopy ifTrue: [
			self
				assert: ('*super postCopy.*' match: source)
				description: class name , '>>' , selector , ' doesn''t call super.'
				resumable: true ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodReturn
	"There should be a space before any return value."
	"self debug: #testMethodReturn"
	
	| source |
	self selectorsDo: [ :class :selector |
		source := (self originalSourceCodeIn: class at: selector)
			readStream.
		[ source atEnd ] whileFalse: [
			source upTo: $^ .
			source atEnd ifFalse: [
				self
					assert: (source next = Character space)
					description: class name , '>>' , selector , ' doesn''t has a missing space before return.'
					resumable: true ] ] ].! !

!MAConventionTests methodsFor: 'testing-methods' stamp: 'lr 5/8/2005 20:30'!
testMethodTagged
	"Tagged code is usually a bad sign."
	"self debug: #testMethodTagged"
	
	self selectorsDo: [ :class :selector |
		 self
			deny: ((class >> selector) literals includesAnyOf: #( 
				#flag:
				#shouldBeImplemented ))
			description: class name , '>>' , selector , ' is tagged.'
			resumable: true ].! !

!MAConventionTests methodsFor: 'testing-classes' stamp: 'lr 5/8/2005 20:30'!
testMethodUnclassified
	"All methods should be classified."
	"self debug: #testMethodUnclassified"
	
	self classesDo: [ :class |
		self
			deny: (class organization categories includes: #'as yet unclassified')
			description: class name , ' has got unclassified method(s).'
			resumable: true ].! !
